@@ -1,11 +1,14 @@
-
-use std::env;
 use ndarray::prelude::*;
-use pyo3::{prelude::*, types::PyList, types::IntoPyDict};
 use numpy::ToPyArray;
+use pyo3::{prelude::*, types::IntoPyDict, types::PyList};
+use std::env;
 
-pub fn plot_py(source_samples: &Array2<f64>, target_samples: &Array2<f64>, ot_matrix: &Array2<f64>, title: &str) -> PyResult<()> {
-
+pub fn plot_py(
+    source_samples: &Array2<f64>,
+    target_samples: &Array2<f64>,
+    ot_matrix: &Array2<f64>,
+    title: &str,
+) -> PyResult<()> {
     let source_y = source_samples.slice(s![.., 1]);
     let target_y = target_samples.slice(s![.., 1]);
 
@@ -18,7 +21,8 @@ pub fn plot_py(source_samples: &Array2<f64>, target_samples: &Array2<f64>, ot_ma
 
     // Import plotting function by adding python script to path
     let pwd = env::current_dir()?;
-    let syspath: &PyList = py.import("sys")
+    let syspath: &PyList = py
+        .import("sys")
         .unwrap()
         .getattr("path")
         .unwrap()
@@ -34,11 +38,16 @@ pub fn plot_py(source_samples: &Array2<f64>, target_samples: &Array2<f64>, ot_ma
     let ot_matrix_py = ot_matrix.to_pyarray(py);
 
     // Plot by calling into matplotlib via python script
-    plt.call_method("figure", (4,), Some(vec![("figsize", (5,5))].into_py_dict(py)))?;
-    plot_mod.getattr("plot1D_mat")?.call1( (source_y_py, target_y_py, ot_matrix_py, title) )?;
+    plt.call_method(
+        "figure",
+        (4,),
+        Some(vec![("figsize", (5, 5))].into_py_dict(py)),
+    )?;
+    plot_mod
+        .getattr("plot1D_mat")?
+        .call1((source_y_py, target_y_py, ot_matrix_py, title))?;
 
     plt.getattr("show")?.call0()?;
 
     Ok(())
-
 }
